// $Id: V9990Renderer.cc,v 1.7 2005/08/27 22:06:01 m9710797 Exp $

#include "V9990Renderer.hh"

namespace openmsx {

/** Dummy Default Renderer. Any real renderer should override all
  * methods mentioned here...
  */
V9990Renderer::V9990Renderer()
{
}

V9990Renderer::~V9990Renderer()
{
}

void V9990Renderer::reset(const EmuTime& /*time*/)
{
}

void V9990Renderer::frameEnd(const EmuTime& /*time*/)
{
}

void V9990Renderer::renderUntil(const EmuTime& /*time*/)
{
}

} // namespace openmsx
